# cobalt

AES encryption with a discord context in mind.

# Installation instructions:

## On Windows

Please open Powershell (NOT as administrator) and run:

`cmd.exe \c "$(curl -fsSL https://raw.githubusercontent.com/8o-COLLECTIVE/cobalt8/development/install/install.bat)"`


## On Unix

Run:

`python3 -m pip install cobalt8`


## Build instructions:

`python3 -m build`

creates the `dist/` directory, containing the wheel for cobalt8.
